package org.apache.torque.generated.peer;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.sql.Connection;
import java.util.List;

import org.apache.torque.BaseDatabaseTestCase;
import org.apache.torque.TooManyRowsException;
import org.apache.torque.Torque;
import org.apache.torque.criteria.Criteria;
import org.apache.torque.test.Author;
import org.apache.torque.test.AuthorPeer;

/**
 * Tests simple selects.
 *
 * @version $Id: SelectTest.java 1336199 2012-05-09 13:34:45Z tfischer $
 */
public class SelectTest extends BaseDatabaseTestCase
{
    private List<Author> authorList;

    @Override
    public void setUp() throws Exception
    {
        super.setUp();
        cleanBookstore();
        authorList = insertBookstoreData();
    }

    /**
     * Tests a select using an Integer comparison.
     *
     * @throws Exception if the test fails
     */
    public void testSelectInteger() throws Exception
    {
        Criteria criteria = new Criteria().where(
                AuthorPeer.AUTHOR_ID,
                authorList.get(0).getAuthorId());

        List<Author> result = AuthorPeer.doSelect(criteria);
        assertEquals("Expected result of size 1 but got " + result.size(),
                1,
                result.size());
        Author author = result.get(0);
        assertEquals("Expected author with Id "
                + authorList.get(0).getAuthorId()
                + " at first position but got "
                + author.getAuthorId(),
                authorList.get(0).getAuthorId(),
                author.getAuthorId());
    }

    /**
     * Tests a select where the column is on the right hand side
     * of the comparison.
     *
     * @throws Exception if the test fails
     */
    public void testSelectIntegerAsLvalue() throws Exception
    {
        Criteria criteria = new Criteria().where(
                authorList.get(0).getAuthorId(),
                AuthorPeer.AUTHOR_ID);

        List<Author> result = AuthorPeer.doSelect(criteria);
        assertEquals("Expected result of size 1 but got " + result.size(),
                1,
                result.size());
        Author author = result.get(0);
        assertEquals("Expected author with Id "
                + authorList.get(0).getAuthorId()
                + " at first position but got "
                + author.getAuthorId(),
                authorList.get(0).getAuthorId(),
                author.getAuthorId());
    }

    /**
     * Tests a select by the doSelectSingleRecord method.
     *
     * @throws Exception if the test fails
     */
    public void testSelectSingleRecord() throws Exception
    {
        Criteria criteria = new Criteria().where(
                AuthorPeer.AUTHOR_ID,
                authorList.get(0).getAuthorId());

        Author author = AuthorPeer.doSelectSingleRecord(criteria);
        assertEquals("Expected author with Id "
                + authorList.get(0).getAuthorId()
                + " but got "
                + author.getAuthorId(),
                authorList.get(0).getAuthorId(),
                author.getAuthorId());
    }

    /**
     * Tests a select by the doSelectSingleRecord method with a connection.
     *
     * @throws Exception if the test fails
     */
    public void testSelectSingleRecordWithConnection() throws Exception
    {
        Criteria criteria = new Criteria().where(
                AuthorPeer.AUTHOR_ID,
                authorList.get(0).getAuthorId());

        Connection connection = Torque.getConnection();
        Author author = AuthorPeer.doSelectSingleRecord(criteria, connection);
        Torque.closeConnection(connection);
        assertEquals("Expected author with Id "
                + authorList.get(0).getAuthorId()
                + " but got "
                + author.getAuthorId(),
                authorList.get(0).getAuthorId(),
                author.getAuthorId());
    }

    /**
     * Tests a select by the doSelectSingleRecord method by passing
     * a database object.
     *
     * @throws Exception if the test fails
     */
    public void testSelectSingleRecordWithObject() throws Exception
    {
       Author author = AuthorPeer.doSelectSingleRecord(authorList.get(0));
        assertEquals("Expected author with Id "
                + authorList.get(0).getAuthorId()
                + " but got "
                + author.getAuthorId(),
                authorList.get(0).getAuthorId(),
                author.getAuthorId());
    }

    /**
     * Tests a select by the doSelectSingleRecord method if no result is found.
     *
     * @throws Exception if the test fails
     */
    public void testSelectSingleRecordResultNull() throws Exception
    {
        Criteria criteria = new Criteria().where(
                AuthorPeer.AUTHOR_ID,
                -1);

        Author author = AuthorPeer.doSelectSingleRecord(criteria);
        assertEquals(null, author);
    }

    /**
     * Tests a select by the doSelectSingleRecord method if too many records
     * are found.
     *
     * @throws Exception if the test fails
     */
    public void testSelectSingleRecordTooManyRecords() throws Exception
    {
        Criteria criteria = new Criteria();

        try
        {
            AuthorPeer.doSelectSingleRecord(criteria);
            fail("Exception expected");
        }
        catch (TooManyRowsException e)
        {
            // expected
        }
    }
}
